@@ -12,7 +12,13 @@ from urllib.request import urlretrieve
 import sys
 import random
 
-
+def oreintation(img,mode):
+    h,w,l=img.shape
+    if mode=='potrait' and h<w:
+        return True
+    elif mode=='landscape' and h>w:
+        return True
+    return False
 
 
 
@@ -33,36 +39,46 @@ class buildDataset():
     def generatecsv(self):
         return None
 
-def videoToFrames(source,dest):
+def videoToFrames(source,dest,mode='potrait',rotation="clockwise"):
+    import cv2
+    if rotation not in ['clockwise','anticlockwise'] or mode not in ['landscape','potrait']:
+        assert "Incorrect shape arguments"
     video = cv2.VideoCapture(source)
     flag, frame = video.read()
     count = 0
     while flag:
         print(dest+"frame%d.jpg" % count)
+        if oreintation(frame,mode='potrait'):
+            if rotation=="clockwise":
+                frame = cv2.rotate(frame, cv2.cv2.ROTATE_90_CLOCKWISE)
+            elif rotation=="anticlockwise":
+                frame = cv2.rotate(frame, cv2.ROTATE_90_COUNTERCLOCKWISE)
         cv2.imwrite(dest+"frame%d.jpg" % count, frame)  # save frame as JPEG file
         flag, frame = video.read()
         print('Read a new frame: ', flag)
         count += 1
 
 def saveVideoFrames(path,destpath):
-    import cv2
+    import os
+    if not os.path.exists(destpath):
+        os.makedirs(destpath)
     if os.path.isdir(path):
-        source = [path+'/'+f for f in listdir(path) if isfile(join(path, f)) and os.path.splitext(f)[-1].lower()==".mp4"]
+        source = [path+'/'+f for f in listdir(path) if isfile(join(path, f)) and os.path.splitext(f)[-1].lower() in [".mp4",".avi",".mov"]]
         dest = [ f for f in listdir(path) if
-                  isfile(join(path, f)) and os.path.splitext(f)[-1].lower() == ".mp4"]
-
+                  isfile(join(path, f)) and os.path.splitext(f)[-1].lower() in [".mp4",".avi",".mov"]]
         if len(source)==0:
             raise("No video file found!")
     elif os.path.isfile(path):
         ext = os.path.splitext(path)[-1].lower()
-        if ext == ".mp4":
+        dest = [path.replace('/', '\\').split('\\')[-1]]
+        if ext in [".mp4",".avi",".mov"]:
             source=[path]
         else:
             raise('ValueError: file format incorrect')
     else:
         raise("Error: It is a special file (socket, FIFO, device file)")
     for s,d in zip(source,dest):
-        videoToFrames(s, destpath+'/'+d)
+        videoToFrames(s, destpath+'/'+"".join([c for c in d if c.isalpha() or c.isdigit() or c==' ']).rstrip())
 
 
 def is_url_image(image_url):
